@@ -53,7 +53,7 @@ function distcc_build_client:init()
         self._PROJECTDIR = projectdir
         self._WORKDIR = path.join(project_config.directory(), "distcc_build")
     else
-        raise("we need enter a project directory with xmake.lua first!")
+        raise("we need to enter a project directory with xmake.lua first!")
     end
 
     -- init timeout
@@ -249,10 +249,10 @@ function distcc_build_client:compile(program, argv, opt)
             local objectfile_cached, objectfile_infofile = build_cache.get(cachekey)
             if objectfile_cached then
                 os.cp(objectfile_cached, cppinfo.objectfile)
-                -- we need update mtime for incremental compilation
+                -- we need to update mtime for incremental compilation
                 -- @see https://github.com/xmake-io/xmake/issues/2620
                 os.touch(cppinfo.objectfile, {mtime = os.time()})
-                -- we need get outdata/errdata to show warnings,
+                -- we need to get outdata/errdata to show warnings,
                 -- @see https://github.com/xmake-io/xmake/issues/2452
                 if objectfile_infofile and os.isfile(objectfile_infofile) then
                     local extrainfo = io.load(objectfile_infofile)
@@ -526,7 +526,7 @@ function distcc_build_client:_connect_host(host)
         return
     end
 
-    -- we need user authorization?
+    -- Do we need user authorization?
     local user = host.user
     local token = host.token
     if not token and user then
